#
# (C) Tenable Network Security, Inc.
#
# Credit: Felix Leder & Tillmann Werner, Dan Kaminsky
# http://iv.cs.uni-bonn.de/wg/cs/applications/containing-conficker/
#
#

include("compat.inc");
if(description)
{
 script_id(36036);
 script_version("$Revision: 1.5 $");
 script_name(english:"Conficker Detection - Network check");
 script_set_attribute(attribute:"synopsis", value:"The remote host seems to be infected by a variant of the Conficker worm.");
 script_set_attribute(attribute:"description", value:"
The remote host seems to be infected by the Conficker worm. This worm
has several capabilities which allow an attacker to execute arbitrary code
on the remote operating system. 
The remote host might also be attempting to propagate the worm to third
party hosts.");
 script_set_attribute(attribute:"solution", value:"
Update your Antivirus and perform a full scan of the remote operating system.");
 script_set_attribute(attribute:"see_also", value:"http://iv.cs.uni-bonn.de/wg/cs/applications/containing-conficker/");
 script_set_attribute(attribute:"see_also", value:"http://support.microsoft.com/kb/962007");
 script_set_attribute(attribute:"see_also", value:"http://www.nessus.org/u?1f3900d3");
 script_set_attribute(attribute:"cvss_vector", value:"CVSS2#AV:N/AC:L/Au:N/C:C/I:C/A:C");
 script_end_attributes();

 summary["english"] = "Determines the presence of the conficker worm";

 script_summary(english:summary["english"]);
 
 script_category(ACT_GATHER_INFO);
 
 script_copyright(english:"This script is Copyright (C) 2009 Tenable Network Security, Inc.");
 family["english"] = "Windows";
 script_family(english:family["english"]);
 
 script_dependencies("netbios_name_get.nasl", "cifs445.nasl");
 script_require_ports(139, 445);
 exit(0);
}

include ('smb_func.inc');


function  NetPathCanonicalize ()
{
 local_var data, data2, fid, fid2, rep, ret, ret2;

 fid = bind_pipe (pipe:"\browser", uuid:"4b324fc8-1670-01d3-1278-5a47bf6ee188", vers:3);
 if (isnull (fid))
   return 0;
 
 data = class_parameter (name:"a", ref_id:0x00001) +
        class_name(name:"\..\") +
	raw_dword (d:2) +
	class_name (name:"\") + 
	raw_dword (d:1) +
	raw_dword (d:1) ;
 

 data = dce_rpc_pipe_request (fid:fid, code:0x1f, data:data);
 if (!data)
   return 0;

 rep = dce_rpc_parse_response (fid:fid, data:data);
 if (!rep || (strlen(rep) < 16))
   return 0;

 ret = get_dword (blob:rep, pos:strlen(rep)-4);
 ret2 = get_dword (blob:rep, pos:strlen(rep)-12);
 if ( ret2 != 0x5c450000 ) return 0;
 if ( ret == 0x00000057 ) return 1;
 # (should be 0x0000007B)

 return 0;
}

#os = get_kb_item ("Host/OS/smb") ;
#if ("Windows" >!< os) exit(0);

name	= kb_smb_name();
port	= kb_smb_transport();

if ( ! get_port_state(port) ) exit(0);
soc = open_sock_tcp(port);
if ( ! soc ) exit(0);

session_init(socket:soc, hostname:name);

r = NetUseAdd(share:"IPC$");
if ( r == 1 )
{
 ret = NetPathCanonicalize ();
 if (ret == 1)
   security_hole(port:port);

 NetUseDel();
}
